Write Code Questions
------------------------

.. selectquestion:: bsoup_writecode_1_sq_v2
   :fromid: bsoup_writecode1q_v2, bsoup_writecode1q_mu
   :toggle: lock

.. selectquestion:: bsoup_writecode_2_sq_v2
   :fromid: bsoup_writecode2q_v2, bsoup_writecode2qv2_mu
   :toggle: lock


.. selectquestion:: bsoup_writecode_3_sq_v2
   :fromid: bsoup_writecode3q_v2, bsoup_writecode3q_mu
   :toggle: lock


.. selectquestion:: bsoup_writecode_4_sq_v2
   :fromid: bsoup_writecode4q_v2, bsoup_writecode4q_mu
   :toggle: lock


.. selectquestion:: bsoup_writecode_5_sq_v2
   :fromid: bsoup_writecode5q_v2, bsoup_writecode5q_mu
   :toggle: lock

.. selectquestion:: bsoup_writecode_6_sq_v2
  :fromid: bsoup_writecode6q_v2, bsoup_writecode6q_mu
  :toggle: lock

.. selectquestion:: bsoup_writecode_7_sq_v2
  :fromid: bsoup_writecode7q_v2, bsoup_writecode7q_mu
  :toggle: lock


.. selectquestion:: bsoup_writecode_8_sq_v2
  :fromid: bsoup_writecode8q_v2, bsoup_writecode8q_mu
  :toggle: lock

.. selectquestion:: bsoup_writecode_9_sq_v2
  :fromid: bsoup_writecode9q_v2, bsoup_writecode9q_mu
  :toggle: lock


.. selectquestion:: bsoup_writecode_10_sq_v2
  :fromid: bsoup_writecode10q_v2, bsoup_writecode10q_v2_mu
  :toggle: lock
